center_scale: center_scale

Description Usage Arguments Value

View source: R/SpeCon.R

Description

the function to center and scale the Bag of Word Matrix first scale then center, otherwise NaN's can be produced.

Usage

1
center_scale(Mat, center = FALSE, scale = TRUE)

Arguments

Mat

An Matrix

center

Whether to center or not: TRUE or FALSE

scale

Whether to scale or not: TRUE or FALSE

Value

Mat The Matrix after processing


yzhang672/pairGraphText documentation built on May 6, 2019, 8:58 p.m.