createB: createB

Description Usage Arguments Value

View source: R/SBM.R

Description

Create SBM matrix

Usage

1
createB(AdjMat, kms_cluster, kmr_cluster)

Arguments

AdjMat

An Adjacency Matrix

kms_cluster

A vector of cluster assignments for the first type of nodes (senders)

kmr_cluster

A vector of cluster assignments for the second type of nodes (receivers)

Value

SbmMat is the SBM matrix


yzhang672/pairGraphText documentation built on May 6, 2019, 8:58 p.m.